{*************************************************}
{*  QuickReport for Delphi                       *}
{*  Demo Preview form                            *}
{*                                               *}
{*  Shows how to create your own custom preview  *}
{*  screen.                                      *}
{*                                               *}
{*************************************************}

unit Demopreview;

interface

uses
  SysUtils, Windows, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, Gauges, StdCtrls, Spin, Printers,
  ComCtrls, Buttons, QRPrntr, QuickRpt, QRCtrls;

type
// To have a custom preview be used as the default preview,
// you first define an interface class.  You will provide two
// functions for this class, Show, and ShowModal.
// To make this the standard preview window use this code -
//        RegisterPreviewClass( TQRSimplePreviewInterface );
//        repfrm1.quickrep1.Preview;
// You can change the name TQRSimplePreviewInterface if you like.
//
  TQRSimplePreviewInterface = class(TQRPreviewInterface)
  public
    function Show(AQRPrinter : TQRPrinter) : TWinControl; override;
    function ShowModal(AQRPrinter : TQRPrinter): TWinControl; override;
  end;

  TFormPreview = class(TForm)
    Panel1: TPanel;
    LblZoom: TLabel;
    QRPreview1: TQRPreview;
    PrintDialog: TPrintDialog;
    OpenDialog: TOpenDialog;
    LblZoomSize: TLabel;
    ZoomUpDown: TUpDown;
    BBFirst: TBitBtn;
    BBLast: TBitBtn;
    BBPrevious: TBitBtn;
    BBNext: TBitBtn;
    LblPageCount: TLabel;
    BBZoomToFilt: TBitBtn;
    BBPrint: TBitBtn;
    BBLoad: TBitBtn;
    BBExit: TBitBtn;
    btnSave: TBitBtn;
    SaveDialog: TSaveDialog;
    LblPageNum: TLabel;
    pageupdown: TUpDown;
    procedure FormShow(Sender: TObject);
    procedure BtnExitClick(Sender: TObject);
    procedure BtnPrintClick(Sender: TObject);
    procedure ZoomUpDownClick(Sender: TObject; Button: TUDBtnType);
    procedure PageUpDownClick(Sender: TObject; Button: TUDBtnType);
    procedure BBFirstClick(Sender: TObject);
    procedure BBPreviousClick(Sender: TObject);
    procedure BBLastClick(Sender: TObject);
    procedure BBNextClick(Sender: TObject);
    procedure BBZoomToFiltClick(Sender: TObject);
    procedure BBPrintClick(Sender: TObject);
    procedure BBLoadClick(Sender: TObject);
    procedure btnSaveClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure QRPreview1PageAvailable(Sender: TObject; PageNum: Integer);
  private

  public
    { Public declarations }
    procedure ShowPreview(Sender: TObject);
    constructor CreatePreview(AOwner : TComponent; aQRPrinter : TQRPrinter);
  end;

var
  FormPreview: TFormPreview;
  QRPrinter : TQRPrinter;


implementation
{$R *.DFM}

function TQRSimplePreviewInterface.Show(AQRPrinter : TQRPrinter) : TWinControl;
begin
  Result := TFormPreview.CreatePreview(Application, AQRPrinter);
  TFormPreview(Result).Show;
end;

function TQRSimplePreviewInterface.ShowModal(AQRPrinter : TQRPrinter) : TWinControl;
begin
  Result := TFormPreview.CreatePreview(Application, AQRPrinter);
  TFormPreview(Result).ShowModal;
end;

constructor TFormPreview.CreatePreview(AOwner : TComponent; aQRPrinter : TQRPrinter);
begin
  inherited Create(AOwner);
  QRPrinter            := aQRPrinter;
  QRPreview1.QRPrinter := aQRPrinter;
end;

procedure TFormPreview.ShowPreview(Sender: TObject);
begin
  ShowModal;
end;

procedure TFormPreview.FormShow(Sender: TObject);
begin
  PageUpDown.Max          :=QRPrinter.PageCount;
  PageUpDown.Min          :=1;
  QRPreview1.PageNumber   :=1;
  PageUpDown.Position     :=1;
  LblPageNum.Caption      :=IntToStr(PageUpDown.Position);
  LblPageCount.Caption    :=IntToStr(QRPrinter.PageCount);
  //FormPreview.WindowState  :=wsMaximized;
  QRPreview1.ZoomToFit;
  ZoomUpDown.Position     :=QRPreview1.Zoom;
  LblZoomSize.Caption     :=IntToStr(ZoomUpDown.Position);
  PrintDialog.ToPage      :=QRPrinter.PageCount;
  PrintDialog.MaxPage     :=QRPrinter.PageCount;
end;

procedure TFormPreview.BtnExitClick(Sender: TObject);
begin
  qrprinter := nil;
  Close;
end;

procedure TFormPreview.BtnPrintClick(Sender: TObject);
begin
  IF PrintDialog.Execute Then QRPrinter.Print;
end;


procedure TFormPreview.ZoomUpDownClick(Sender: TObject; Button: TUDBtnType);
begin
  QRPreview1.Zoom:=ZoomUpDown.Position;
  QRPreview1.Zoom:=ZoomUpDown.Position;
  LblZoomSize.Caption:=IntToStr(ZoomUpDown.Position);
end;

procedure TFormPreview.PageUpDownClick(Sender: TObject; Button: TUDBtnType);
begin
  QRPreview1.PageNumber:=PageUpDown.Position;
  LblPageNum.Caption:=IntToStr(PageUpDown.Position);
end;

procedure TFormPreview.BBFirstClick(Sender: TObject);
begin
  QRPreview1.PageNumber:=1;
  PageUpDown.Position:=QRPreview1.PageNumber;
  LblPageNum.Caption:=IntToStr(PageUpDown.Position);
end;

procedure TFormPreview.BBPreviousClick(Sender: TObject);
begin
  QRPreview1.PageNumber:=PageUpDown.Position-1;
  PageUpDown.Position:=QRPreview1.PageNumber;
  LblPageNum.Caption:=IntToStr(PageUpDown.Position);
end;

procedure TFormPreview.BBLastClick(Sender: TObject);
begin
  QRPreview1.PageNumber:=QRPrinter.PageCount;
  PageUpDown.Position:=QRPreview1.PageNumber;
  LblPageNum.Caption:=IntToStr(PageUpDown.Position);
end;

procedure TFormPreview.BBNextClick(Sender: TObject);
begin
  QRPreview1.PageNumber:=PageUpDown.Position+1;
  PageUpDown.Position:=QRPreview1.PageNumber;
  LblPageNum.Caption:=IntToStr(PageUpDown.Position);
end;

procedure TFormPreview.BBZoomToFiltClick(Sender: TObject);
begin
  QRPreview1.ZoomToFit;
  ZoomUpDown.Position:=QRPreview1.Zoom;
  LblZoomSize.Caption:=IntToStr(QRPreview1.Zoom);
end;

procedure TFormPreview.BBPrintClick(Sender: TObject);
begin
  IF PrintDialog.Execute Then QRPrinter.Print;
end;

procedure TFormPreview.BBLoadClick(Sender: TObject);
begin
 IF OpenDialog.Execute Then
    Begin
      If QRPrinter.Orientation=PoPortrait Then
        Begin
         Printer.Orientation:=PoLandscape;
         QRPrinter.Orientation:=PoLandscape;
        End
      Else
        Begin
         Printer.Orientation:=PoPortrait;
         QRPrinter.Orientation:=PoPortrait;
        End;

      QRPrinter.Load(OpenDialog.FileName);
      QRPrinter.Preview;
      FormPreview.Hide;
      FormPreview.Show;
    End
end;

procedure TFormPreview.btnSaveClick(Sender: TObject);
begin
  SaveDialog.FileName := 'Test';
  if SaveDialog.Execute then
    begin

      //Write Out Report
    end;
end;

procedure TFormPreview.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  Action := caFree;
end;

procedure TFormPreview.QRPreview1PageAvailable(Sender: TObject;
  PageNum: Integer);
begin
      LblPageCount.Caption := IntToStr(QRPrinter.PageCount);
      PageUpDown.Max := QRPrinter.PageCount;

end;

end.
